@@ -8,11 +8,17 @@
 #'
 #' @returns A numeric vector.
 #' @keywords internal
-
 .calcWeights <- function(w, data, resp, family) {
 
+	fam <- if (inherits(family, 'family')) {
+		family$family
+	} else {
+		family
+	}
+
 	if (inherits(w, 'logical')) {
-		if (w & (family %in% c('binomial', 'quasibinomial'))) {
+
+		if (w & (fam %in% c('binomial', 'quasibinomial'))) {
 			posCases <- sum(data[ , resp, drop=TRUE] == 1)
 			negCases <- sum(data[ , resp, drop=TRUE] == 0)
 			w <- c(rep(1, posCases), rep(posCases / negCases, negCases))
